#!/usr/bin/env python
#
# Copyright 2001-2002 Free Software Foundation
#
# This file is part of GNU Enterprise.
#
# GNU Enterprise is free software; you can redistribute it
# and/or modify it under the terms of the GNU General Public
# License as published by the Free Software Foundation; either
# version 2, or (at your option) any later version.
#
# GNU Enterprise is distributed in the hope that it will be
# useful, but WITHOUT ANY WARRANTY; without even the implied
# warranty of MERCHANTABILITY or FITNESS FOR A PARTICULAR
# PURPOSE. See the GNU General Public License for more details.
#
# You should have received a copy of the GNU General Public
# License along with program; see the file COPYING. If not,
# write to the Free Software Foundation, Inc., 59 Temple Place
# - Suite 330, Boston, MA 02111-1307, USA.
#

import sys
import string
import os
import os.path
import copy

from src import VERSION


#
# hack to deal w/ fact distutils won't
# allow us to set absolute path prefix
# on windows
#

if not 'sdist' in sys.argv:
  if sys.platform != 'win32':
    os.system ("""cp setup.cfg.in setup.cfg""")
  else:
    try:
      os.remove('setup.cfg')
    except:
      pass

try:
  from distutils.core import setup
  from distutils.command.build_scripts import build_scripts
#  from setupext import Data_Files, install_Data_Files
except ImportError:
  print """
Setup requires that python's distutils be
installed.  You can get a copy of it from
http://www.python.org/sigs/distutils-sig/
    """
  sys.exit()


if 'sdist' in sys.argv:
  print """
We are going to create the docs needed for the
source distro.  You'll need texinfo installed.
"""
  raw_input ("Press Control-D to abort or any other key to continue")
  os.system ("""
cd doc/api
make html
make txt
make pdf
cd ../whitepaper
make html
make txt
make pdf
""")

  print "Now, we are going to create the man pages for our tools."
  os.system( """
if [ ! -e man ]
then
mkdir man
fi
cd man
../scripts/gacvs --generate-man-page
""")


if ('build' in sys.argv) or ('install' in sys.argv):

  ## TODO: These checks will not work as gnue.common
  ## TODO: isn't in python's default search path.

#  # Verify that gnue-common is installed
#  try:
#    print "Checking for GNUe-Common....",
#    from gnue import common
#    if common.__dict__.has_key('VERSION'):
#      print "OK (version %s)" % common.VERSION
#    else:
#      print "OK"
#  except ImportError:
#    print """
#You will need to install gnue-common before
#GNUe Application Server will function.  You can
#obtain a copy from
#
#http://www.gnuenterprise.org/download.php
#"""
#    sys.exit()
#
#  # Verify that gnue-common has newest dbdriver/appserver
#  try:
#    print "Checking for dbdriver/appserver....",
#    from gnue.common.dbdrivers.appserver import DBdriver
#    print "OK (version %s)" % DBdriver.VERSION
#
#  except ImportError:
#    print """
#You will need to install newer version of gnue-common before
#GNUe Application Server will function.  You can
#obtain a copy from
#
#http://www.gnuenterprise.org/download.php
#(You need at least version 0.2.0)
#"""
#    sys.exit()
#


  #
  # Verify at least one RPC driver is installed
  #
  RPCOK = 0

  print "Checking for available GNU-RPC drivers...."
  # XMLRPC
  try:
    print "   PY-XMLRPC....",
    import xmlrpc
    print "OK"
    RPCOK = 1
  except ImportError:
    print "No"

  # PW_XMLRPC
  try:
    print "   Pythonware XMLRPC....",
    try:
      import xmlrpclib
    except ImportError:
      from xmlrpclib import xmlrpclib
    print "OK"
    RPCOK = 1
  except ImportError:
    print "No"

  # SOAP
  try:
    print "   SOAP (currently not working)....",
    from SOAP import SOAP
    print "OK"
    RPCOK = 1
  except ImportError:
    print "No"


  if RPCOK != 1:
    print """
No valid GNURRPC drivers are installed on this machine:
   Py-XMLRPC         - http://sourceforge.net/projects/py-xmlrpc
   Pythonware XMLRPC - http://www.pythonware.com/products/xmlrpc/
   SOAP              - ***
   CORBA             - ***
"""
    sys.exit()


# Site config stuff
try:
  index = sys.argv.index('--cfg-file')
  site_config = os.path.join(os.path.abspath(sys.argv[index+1]))
  sys.argv.pop(index)
  sys.argv.pop(index)
  config_line = "os.environ['GNUE_INSTALLED_SITE_CFG']='%s'\n" % site_config

except ValueError:
  config_line = ""



class my_build_scripts(build_scripts):
  def finalize_options(self):

    build_scripts.finalize_options(self)

    if self.finalized:
      return


    if sys.platform != 'win32':
      dict = self.distribution.get_option_dict("install")
      install_prefix = dict['prefix'][1]

      gnue_env = \
           "#######\n" \
         + "# The following variable were set when GNUe was installed\n" \
         + "import os, sys\n" \
         + "sys.path.append('%s')\n" % dict['install_lib'][1] \
         + "INST_GNUE_CONNECTIONS='%s/etc/connections.conf'\n" % dict['prefix'][1] \
         + "os.environ['INSTALL_LIB']='%s'\n" % dict['install_lib'][1] \
         + "os.environ['INSTALL_PREFIX']='%s'\n" % dict['prefix'][1] \
         + config_line \
         + "#######\n"
    else:
      gnue_env = \
               "#######\n" \
             + "# The following variables were set when GNUe was installed\n"    \
             + "# (Generated for a Win32 system)\n" \
             + "import os, sys\n" \
             + "if __name__ == '__main__': \n" \
             + "  _BASE = os.path.abspath(os.path.join(os.path.dirname(sys.argv[0]),'..'))\n" \
             + "  try:\n" \
             + "    os.environ['PATH']= os.path.abspath(os.path.dirname(sys.argv[0])) + ';' + os.environ['PATH']\n" \
             + "  except KeyError:\n" \
             + "    os.environ['PATH']= os.path.abspath(os.path.dirname(sys.argv[0]))\n" \
             + "else: \n" \
             + "  _BASE = os.path.abspath(os.path.join(os.path.dirname(__file__),'..'))\n" \
             + "INST_GNUE_CONNECTIONS=os.path.join(_BASE,'etc','connections.conf')\n" \
             + "os.environ['INSTALL_PREFIX']=_BASE\n"                \
             + "os.environ['INSTALL_LIB']=_BASE\n"                   \
             + "os.putenv('PYTHONCASEOK','1')\n" \
             + config_line \
             + "if os.path.isdir(os.path.join(_BASE,'extras')):\n" \
             + "  sys.path.append(os.path.join(_BASE,'extras'))\n" \
             + "#######\n\n"

    for script in self.scripts:
      print "Building %s..."% (script),


      fin = open(script+".in", "r")
      fout = open(script, "w")

      print "Generating script %s from %s.in" % (script,script)

      lines = fin.readlines()

      for i in range(0, len(lines)):
        if string.strip(lines[i]) == "__GNUEENV__":
          lines[i] = gnue_env

      fout.writelines(lines)
      fin.close()
      fout.close()
      print "OK"

docfiles = ['README', 'INSTALL', 'AUTHORS', 'COPYING', 'NEWS', 'THANKS']
for file in ('doc/api/api.html',
             'doc/api/api.txt',
             'doc/api/api.pdf',
             'doc/whitepaper/whitepaper.html',
             'doc/whitepaper/whitepaper.txt',
             'doc/whitepaper/whitepaper.pdf'):
  if os.path.isfile(file):
    docfiles.append(file)
  else:
    print "WARNING: File %s does not exist... not installing!" % file

manfiles = []
for file in ('man/gnue-appserver.1',
             'man/gnue-appserver.1'):
  if os.path.isfile(file):
    manfiles.append(file)
  else:
    print "WARNING: File %s does not exist... not installing!" % file



#
# You can run:
#   $ GNUE_VERSION_SUFFIX=-pre1 ./setup.py sdist
# and the packages will be created as GNUe-App-0.x.x-pre1.tar.gz
#
try:
  suffix = os.environ['GNUE_VERSION_SUFFIX']
except KeyError:
  suffix = ""

setup (name = "GNUe-AppServer",
       version = VERSION + suffix,
       description = "GNU Enterprise Application Server",
       long_description = "",
       author = "GNUe Application Server Team",
       author_email = "gnue-gnue-appserver@gnue.org",
       url = "http://www.gnue.org",

       # Override certain command classes with our own ones
       cmdclass = {'build_scripts':my_build_scripts},

       data_files = [ ('doc/appserver', docfiles),
                      ('man/man1', manfiles),
                      ('samples/appserver',['samples/appservertest.gfd',
                                  'samples/setup-pgsql.sh',
#                                  'samples/setup-mysql.sh'
                              ]),
                      ('shared/grpc',['grpc/GEAS.grpc'])
                       ],

       packages = ["gnue.appserver",
                   "gnue.appserver.objrepos",],
       package_dir = {"gnue.appserver" : "src"},
       scripts = ["scripts/gnue-appserver"]
       )

if 'install' in sys.argv:
    print """
    Note:
    Warnings about the files not being installed in pythons search path can be ignored.

    Make sure you have a default gnue.conf file (typically in /usr/local/gnue/etc.
    A sample is provided in that directory that you can typically just copy over.
    """

if not 'sdist' in sys.argv:
  if sys.platform != 'win32':
    os.system (""" /bin/rm -rf setup.cfg""")












