# GNU Enterprise Application Server - Authentification Services
#
# Copyright 2001 Free Software Foundation
#
# This file is part of GNU Enterprise.
#
# GNU Enterprise is free software; you can redistribute it 
# and/or modify it under the terms of the GNU General Public 
# License as published by the Free Software Foundation; either 
# version 2, or (at your option) any later version.
#
# GNU Enterprise is distributed in the hope that it will be 
# useful, but WITHOUT ANY WARRANTY; without even the implied 
# warranty of MERCHANTABILITY or FITNESS FOR A PARTICULAR 
# PURPOSE. See the GNU General Public License for more details.
#
# You should have received a copy of the GNU General Public 
# License along with program; see the file COPYING. If not, 
# write to the Free Software Foundation, Inc., 59 Temple Place 
# - Suite 330, Boston, MA 02111-1307, USA.
#
# $Id: geasAuthentification.py,v 1.1 2002/06/05 19:15:58 siesel Exp $

import geasList
import string

# =============================================================================
# Basic Authentification Class ( abstract )
# =============================================================================

class geasAuthAgent:

  # ---------------------------------------------------------------------------
  # Initalize
  # ---------------------------------------------------------------------------

  def __init__ (self):
    pass

  # ---------------------------------------------------------------------------
  # authentificate an user
  # user contains the user name
  # auth contains authentification information (like password, fingerprint...)
  # return 1 on access ok  (0=access denied)
  # ---------------------------------------------------------------------------

  def authentificate(self, session, user, auth):
    return 1
    

  # ---------------------------------------------------------------------------
  # 
  # check if user x has access for class/table y
  # return 1 on access ok  (0=access denied)
  # ---------------------------------------------------------------------------

  def hasAccess (self, session, user, classname):    
    return 1
    

# =============================================================================
# Database Authentification Agent 
# =============================================================================

class geasDBAuthAgent(geasAuthAgent):

  # ---------------------------------------------------------------------------
  # Initalize
  # ---------------------------------------------------------------------------

  def __init__ (self):
    # creation and populating the user/password/tablelist list should be
    # moved here, when the management interface is implemented and an easy
    # way to update permissions is working
    pass

  # ---------------------------------------------------------------------------
  # authentificate an user
  # user contains the user name
  # auth contains authentification information (like password, fingerprint...)
  # return 1 on access ok  (0=access denied)
  # ---------------------------------------------------------------------------

  def authentificate(self, session, user, auth):
    authList=geasList.geasList (session,'appserver_users')

    authList.setPrefetch (["username", "password", "tablelist"])
    authList.setConditions ([['eq', ''],
                             ['field', 'username'],
                             ['const', user ]])
    authList.populate ()

    instance = authList.firstInstance ()
    
    # no such user
    if instance==None:
      # log something
      print _("User '%s' does not exist.") % user
      
      return 0 # = no access

    if instance.get('password')!=auth['password']:
      # log something
      print _("User '%s' didn't provide right authentification information"+
              " (password).") % user
      
      return 0 # = no access

    print _("User '%s' logged in.") % user

    # possibly not the best solution
    session._tablelist=string.split(instance.get('tablelist'),',')
    
    return 1 # = has access
       

  # ---------------------------------------------------------------------------
  # 
  # check if user x has access for class/table y
  # ---------------------------------------------------------------------------

  def hasAccess (self, session, user, classname):
    # this should be changed to check for the user again.
    # it will only be secure if the protocol supports session-management too.
    if hasattr(session,"_tablelist") and (classname in session._tablelist):      
      return 1
    else:
      return 0  
    
    
